@@ -3,12 +3,12 @@ import dataclasses
 from abc import ABC, abstractmethod
 from typing import Iterator, Type, TypeAlias, Callable, Any
 from .. import settings
-from ..types import common_data_types as cdt, useful_types as ut, cosem_service_types as cst
+from ..types import cdt, ut, cst
 from ..relation_to_OBIS import get_name
 import logging
-import multiprocessing
 from enum import IntEnum
 from datetime import datetime, timedelta, timezone
+from itertools import count
 from . import collection as col
 
 match settings.get_current_language():
@@ -20,20 +20,7 @@ logger.level = logging.INFO
 
 logger.info(F'Register start')
 
-
-_COSEM_interface_class_ids:  set[int] = set()
-""" registered class_id """
-print('init-Cosem', multiprocessing.current_process())
-
-
-def get_COSEM_class_amount() -> int:
-    """ Amount of different registered DLMS classes """
-    return len(_COSEM_interface_class_ids)
-
-
-def is_class_id_exist(value: int) -> bool:
-    """ check for existing class ID """
-    return value in _COSEM_interface_class_ids
+_n_class = count(0)
 
 
 class Classifier(IntEnum):
@@ -121,6 +108,10 @@ class COSEMInterfaceClasses(ABC):
 
         self.characteristics_init()
 
+    def __init_subclass__(cls, **kwargs):
+        super().__init_subclass__(**kwargs)
+        cls.hash_ = next(_n_class)
+
     @classmethod
     def get_attr_element(cls, i: int) -> ICAElement:
         """return element by order index. Override in each new class"""
@@ -214,14 +205,6 @@ class COSEMInterfaceClasses(ABC):
     def NAME(self) -> str:
         """ class name according to current language """
 
-    def __init_subclass__(cls, **kwargs):
-        """ register subclass in COSEM interface classes with unique class ID  """
-        super().__init_subclass__(**kwargs)
-        if cls.VERSION is None:  # for common classes
-            return
-        print(F'Init {cls.__name__} ver{cls.VERSION}')
-        _COSEM_interface_class_ids.add(int(cls.CLASS_ID))
-
     @property
     def logical_name(self) -> cst.LogicalName:
         """ The logical name is always the first attribute of a class. It identifies the instantiation (COSEM object) of this class.
