@@ -8,8 +8,8 @@ class ExtendedRegister(register.Register, ic.COSEMInterfaceClasses):
     the nature of the process value or of the status value. The nature of the value is described by the attribute
     “logical name” using the OBIS identification system. """
     NAME = cn.EXTENDED_REGISTER
-    CLASS_ID = ut.CosemClassId(class_id.EXT_REGISTER)
-    VERSION = cdt.Unsigned(0)
+    CLASS_ID = ClassID.EXT_REGISTER
+    VERSION = Version.V0
     A_ELEMENTS = (register.Register.get_attr_element(2),
                   register.Register.get_attr_element(3),
                   ic.ICAElement(an.STATUS, choices.extended_register, classifier=ic.Classifier.DYNAMIC),
