@@ -1,4 +1,5 @@
 from __future__ import annotations
+from functools import lru_cache
 from abc import ABC, abstractmethod
 from typing import Type, Any, Callable
 from dataclasses import dataclass
@@ -8,16 +9,21 @@ from ..types import common_data_types as cdt
 class _String(ABC):
     LENGTH: int | None
 
-    def __init__(self, value: bytes | bytearray | str | int | UsefulType = None):
+    def __init__(self, value: bytes | bytearray | str | int | tuple | UsefulType = None):
         match value:
-            case None:                                                        self.contents = bytes(self.LENGTH)
-            case bytes() if self.LENGTH is None or self.LENGTH <= len(value): self.contents = value[:self.LENGTH]
+            case None:                                                        self.__dict__["contents"] = bytes(self.LENGTH)
+            case bytes() if self.LENGTH is None or self.LENGTH <= len(value): self.__dict__["contents"] = value[:self.LENGTH]
             # case bytes() if self.LENGTH <= len(value):                       self.contents = value[:self.LENGTH]
             case bytes():            raise ValueError(F'Length of contents for {self.__class__.__name__} must be at least {self.LENGTH}, but got {len(value)}')
-            case bytearray():                                                 self.contents = bytes(value)  # Attention!!! changed method content getting from bytearray
-            case str():                                                       self.contents = self.from_str(value)
-            case int():                                                       self.contents = self.from_int(value)
-            case UsefulType():                                                self.contents = value.contents  # TODO: make right type
+            case tuple():
+                if len(value) == self.LENGTH:
+                    self.__dict__["contents"] = bytes(value)
+                else:
+                    raise ValueError(F"in {self.__class__.__name__} with {value=} got length: {len(value)}, expect {self.LENGTH}")
+            case bytearray():                                                 self.__dict__["contents"] = bytes(value)  # Attention!!! changed method content getting from bytearray
+            case str():                                                       self.__dict__["contents"] = self.from_str(value)
+            case int():                                                       self.__dict__["contents"] = self.from_int(value)
+            case UsefulType():                                                self.__dict__["contents"] = value.contents  # TODO: make right type
             case _:                                                           raise ValueError(F'Error create {self.__class__.__name__} with value {value}')
 
     @abstractmethod
@@ -186,6 +192,9 @@ class SEQUENCE(ABC):
     def __str__(self):
         return F'{{{", ".join(map(lambda val: F"{val[0].NAME}: {val[1]}", zip(self.ELEMENTS, self.values)))}}}'
 
+    def __repr__(self):
+        return F'{self.__class__.__name__}(({(", ".join(map(str, self.values)))}))'
+
     def __get_index(self, name: str) -> int | None:
         """ get index by name. Return None if not found """
         for i, element in enumerate(self.ELEMENTS):
@@ -269,14 +278,14 @@ class DigitalMixin(ABC):
 
     def __init__(self, value: bytes | bytearray | str | int | DigitalMixin = None):
         match value:
-            case bytes() if self.LENGTH <= len(value): self.contents = value[:self.LENGTH]
+            case bytes() if self.LENGTH <= len(value): self.__dict__["contents"] = value[:self.LENGTH]
             case bytes():            raise ValueError(F'Length of contents for {self.__class__.__name__} must be at least {self.LENGTH}, but got {len(value)}')
-            case bytearray():                          self.contents = bytes(value)  # Attention!!! changed method content getting from bytearray
-            case str('-') if self.SIGNED:              self.contents = bytes(self.LENGTH)
-            case int():                                self.contents = self.from_int(value)
-            case str():                                self.contents = self.from_str(value)
-            case None:                                 self.contents = bytes(self.LENGTH)
-            case self.__class__():                     self.contents = value.contents
+            case bytearray():                          self.__dict__["contents"] = bytes(value)  # Attention!!! changed method content getting from bytearray
+            case str('-') if self.SIGNED:              self.__dict__["contents"] = bytes(self.LENGTH)
+            case int():                                self.__dict__["contents"] = self.from_int(value)
+            case str():                                self.__dict__["contents"] = self.from_str(value)
+            case None:                                 self.__dict__["contents"] = bytes(self.LENGTH)
+            case self.__class__():                     self.__dict__["contents"] = value.contents
             case _:                                    raise ValueError(F'Error create {self.__class__.__name__} with value: {value}')
 
     def from_int(self, value: int | float) -> bytes:
@@ -377,7 +386,7 @@ class CosemObjectInstanceId(OCTET_STRING, UsefulType):
     LENGTH = 6
 
     def __str__(self):
-        return '.'.join(map(str, self.contents))
+        return F"\"{'.'.join(map(str, self.contents))}\""
 
     def from_str(self, value: str) -> bytes:
         """ create logical_name: octet_string from string type ddd.ddd.ddd.ddd.ddd.ddd, ex.: 0.0.1.0.0.255 """
@@ -416,6 +425,10 @@ class CosemObjectInstanceId(OCTET_STRING, UsefulType):
 class CosemObjectAttributeId(Integer8):
     """ TODO """
 
+    @lru_cache(14)  # for test
+    def __new__(cls, *args, **kwargs):
+        return super().__new__(cls)
+
 
 class CosemObjectMethodId(Integer8):
     """ TODO """
